summaryrefslogtreecommitdiffstats
path: root/components/favicon_base/favicon_util.h
diff options
context:
space:
mode:
Diffstat (limited to 'components/favicon_base/favicon_util.h')
-rw-r--r--components/favicon_base/favicon_util.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/components/favicon_base/favicon_util.h b/components/favicon_base/favicon_util.h
index ee59428..912f06f 100644
--- a/components/favicon_base/favicon_util.h
+++ b/components/favicon_base/favicon_util.h
@@ -8,7 +8,6 @@
#include <vector>
#include "components/favicon_base/favicon_types.h"
-#include "ui/base/layout.h"
namespace gfx {
class Image;
@@ -16,24 +15,25 @@ class Image;
namespace favicon_base {
// Returns the scale factors at which favicons should be fetched. This is
// different from ui::GetSupportedScaleFactors() because clients which do
// not support 1x should still fetch a favicon for 1x to push to sync. This
// guarantees that the clients receiving sync updates pushed by this client
// receive a favicon (potentially of the wrong scale factor) and do not show
// the default favicon.
-std::vector<ui::ScaleFactor> GetFaviconScaleFactors();
+std::vector<float> GetFaviconScales();
// Sets the color space used for converting |image| to an NSImage to the
// system colorspace. This makes the favicon look the same in the browser UI
// as it does in the renderer.
void SetFaviconColorSpace(gfx::Image* image);
// Takes a vector of png-encoded frames, decodes them, and converts them to
// a favicon of size favicon_size (in DIPs) at the desired ui scale factors.
gfx::Image SelectFaviconFramesFromPNGs(
const std::vector<favicon_base::FaviconRawBitmapResult>& png_data,
- const std::vector<ui::ScaleFactor>& scale_factors,
+ const std::vector<float>& favicon_scales,
int favicon_size);
} // namspace favicon_base
@@ -16,24 +15,25 @@ class Image;
namespace favicon_base {
-// Returns the scale factors at which favicons should be fetched. This is
+// Returns the scales at which favicons should be fetched. This is
// different from ui::GetSupportedScaleFactors() because clients which do
// not support 1x should still fetch a favicon for 1x to push to sync. This
@@ -16,24 +15,25 @@ class Image;
// as it does in the renderer.
void SetFaviconColorSpace(gfx::Image* image);
-// Takes a vector of png-encoded frames, decodes them, and converts them to
-// a favicon of size favicon_size (in DIPs) at the desired ui scale factors.
+// Takes a vector of PNG-encoded frames, and converts it to a gfx::Image of
+// size |favicon_size| in DIPS. The result gfx::Image has a gfx::ImageSkia with
+// gfx::ImageSkiaReps for each |favicon_scales|.
gfx::Image SelectFaviconFramesFromPNGs(
const std::vector<favicon_base::FaviconRawBitmapResult>& png_data,